Clazz.declarePackage("J.jvxl.api");
Clazz.declareInterface(J.jvxl.api, "MeshDataServer", J.jvxl.api.VertexDataServer);
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
